@@ -76,7 +76,7 @@ from de.setup_project import (
     code_file_version, pev_str, pev_val, project_env_vars)
 
 
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 
 # --------------- global constants ------------------------------------------------------------------------------------
@@ -891,10 +891,11 @@ def _check_types_linting_tests(pdv: PdvType):
             _cl(62, f"touch {namespace_name}/__init__.py")
         out: List[str] = []
         _cl(62, f"pylint --output-format=text --max-line-length={line_len} {ignore_options} {' '.join(args)}",
-            _exit_on_err=False, lines_output=out)   # instead of _exit_on_err, put the pylint option --exit-zero
+            _exit_on_err=False, lines_output=out)   # alternative to _exit_on_err: run pylint with option --exit-zero
         matcher = re.search("Your code has been rated at ([-0-9.]*)", os.linesep.join(out))
         if not matcher:
             _exit_error(62, f"   ** pylint score search failed in string {os.linesep.join(out)}")
+        write_file(os.path.join(".pylint", "pylint.log"), os.linesep.join(out))
         score = matcher.group(1)                                                                    # type: ignore
         _cl(62, f"anybadge -o --label=Pylint --file=.pylint/pylint.svg --value={score}"
                 " 2=red 4=orange 8=yellow 10=green")
